# PyDload

# Installation
```
pip install pydload
```

# Usage
```
import pydload
pydload.dload('url', 'out_path')
```

# Optional Params

max_time - default:30sec. If download takes more than max_time stop download.

timeout - default:10sec. Requests timeout. Max time allowed for establishing connection.
